====================
Tables of transforms
====================

.. _fourier_transforms:

Fourier Transforms
==================

Lcapy can compute many Fourier transforms including:

.. include:: fourier_transforms.rst


.. _laplace_transforms:

Laplace Transforms
==================

Lcapy can compute many Laplace transforms including:

.. include:: laplace_transforms.rst

.. _z_transforms:

Z Transforms
============

Lcapy can compute many Z transforms including:

.. include:: ztransforms.rst
             
